==> soliq_id-1.2.29.tar.gz: lib/src/utils/choose_language.dart <==
import 'dart:developer';

import 'package:flutter/material.dart';
import 'package:flutter_svg/svg.dart';
import 'package:logger/logger.dart';
import 'package:soliq_id/src/utils/utils.dart';

import '../../soliq_id.dart';
import 'faceid_localizations.dart';

class ChooseLanguage extends StatefulWidget {
  final bool changeOnServer;

  const ChooseLanguage({Key? key, this.changeOnServer = true})
      : super(key: key);

  @override
  _ChooseLanguageState createState() => _ChooseLanguageState();
}

class _ChooseLanguageState extends State<ChooseLanguage> {
  int _selectLanguage = 0;
  bool _loadingLanguage = false;
  var langCode = ["uz", "eng", "ru","ka","en"];

  @override
  Widget build(BuildContext context) {
    initCurrentLang();
    return Stack(
      children: [
        Padding(
          padding:const EdgeInsets.only(
            left: (20),
            right: (20),
            top: (16),
            bottom: (40),
          ),
          child: Column(
            children: [
              Center(
                child: Text(
                  getTranslated(context, 'changeLanguage'),
                  style:const TextStyle(fontSize: 16),
                ),
              ),
              const SizedBox(height: (16),),
              SoliqSelectButton(
                id: 0,
                text: "O’zbek tili",
              ),
              SoliqSelectButton(
                id: 1,
                text: "English",
              ),
              SoliqSelectButton(
                id: 2,
                text: "Русский язык",
              ),
              SoliqSelectButton(
                id: 3,
                text: "Qaraqalpaqsha",
              ),
              SoliqSelectButton(
                id: 4,
                text: "Ўзбек тили",
              ),
            ],
          ),
        ),
        const Positioned(
          top: 0,
          bottom: 0,
          left: 0,
          right: 0,
          child: SizedBox(
              height: 200,
               child: SizedBox()),
        )
      ],
    );
  }

  Future<void> initCurrentLang() async {
    String? langCode = await pref?.getLang();

    setState(() {
      switch (langCode) {
        case 'uz':
          _selectLanguage = 0;
          break;
        case 'eng':
          _selectLanguage = 1;
          break;
        case 'ru':
          _selectLanguage = 2;
          break;
        case 'ka':
          _selectLanguage = 3;
          break;
        case 'en':
          _selectLanguage = 4;
          break;
      }
    });
  }

  SoliqSelectButton({required int id, required String text}) {
    return Padding(
      padding:const EdgeInsets.symmetric(vertical: 8.0),
      child: Stack(
        alignment: Alignment.center,
        children: [
          ElevatedButton(
            style: ElevatedButton.styleFrom(
              elevation: 4.0,
              shadowColor: Colors.black12,
              backgroundColor: Colors.white,
              shape: RoundedRectangleBorder(
                  borderRadius: BorderRadius.circular(10.0)),
              padding:const EdgeInsets.symmetric(
                horizontal: 30,
                vertical: 18,
              ),
            ),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                Center(
                  child: Text(
                    text,
                    textAlign: TextAlign.center,
                    style:const TextStyle(
                      color: Colors.grey,
                      fontSize: 14,
                      fontFamily: 'Montserrat',
                      fontWeight: FontWeight.w500,
                    ),
                  ),
                ),
              ],
            ),
            onPressed: () => changeLanguage(id),
          ),
          Padding(
            padding: const EdgeInsets.only(right: 20.0),
            child: Align(
              alignment: Alignment.centerRight,
              child: _selectLanguage == id
                  ? SvgPicture.asset(
                      'assets/icons/check.svg',
                      // color: primaryAppColor(context),
                    )
                  : Container(),
            ),
          )
        ],
      ),
    );
  }

  Future<void> changeLanguage(int id) async {
    try {
      setState(() {
        _loadingLanguage = true;
      });

      log("////////////////////////${langCode[id]}");

      await Utils.changeLanguage(context, langCode[id],
          changeOnServer: widget.changeOnServer);
      setState(() {
        _loadingLanguage = false;
      });
      Navigator.pop(context);
    } catch (e) {
      Logger().d(e);
    }
  }
}

==> soliq_id-1.2.49.tar.gz: lib/src/utils/choose_language.dart <==
import 'dart:developer';

import 'package:flutter/material.dart';
import 'package:flutter_svg/svg.dart';
import 'package:logger/logger.dart';
import 'package:soliq_id/src/utils/utils.dart';

import '../../soliq_id.dart';
import 'faceid_localizations.dart';

class ChooseLanguage extends StatefulWidget {
  final bool changeOnServer;

  const ChooseLanguage({Key? key, this.changeOnServer = true})
      : super(key: key);

  @override
  _ChooseLanguageState createState() => _ChooseLanguageState();
}

class _ChooseLanguageState extends State<ChooseLanguage> {
  int _selectLanguage = 0;
  bool _loadingLanguage = false;
  var langCode = ["uz", "eng", "ru","ka","en"];

  @override
  Widget build(BuildContext context) {
    initCurrentLang();
    return Stack(
      children: [
        Padding(
          padding:const EdgeInsets.only(
            left: (20),
            right: (20),
            top: (16),
            bottom: (40),
          ),
          child: Column(
            children: [
              Center(
                child: Text(
                  getTranslated(context, 'changeLanguage'),
                  style:const TextStyle(fontSize: 16),
                ),
              ),
              const SizedBox(height: (16),),
              SoliqSelectButton(
                id: 0,
                text: "O’zbek tili",
              ),
              SoliqSelectButton(
                id: 1,
                text: "English",
              ),
              SoliqSelectButton(
                id: 2,
                text: "Русский язык",
              ),
              SoliqSelectButton(
                id: 3,
                text: "Qaraqalpaqsha",
              ),
              SoliqSelectButton(
                id: 4,
                text: "Ўзбек тили",
              ),
            ],
          ),
        ),
        const Positioned(
          top: 0,
          bottom: 0,
          left: 0,
          right: 0,
          child: SizedBox(
              height: 200,
               child: SizedBox()),
        )
      ],
    );
  }

  Future<void> initCurrentLang() async {
    String? langCode = await pref?.getLang();

    setState(() {
      switch (langCode) {
        case 'uz':
          _selectLanguage = 0;
          break;
        case 'eng':
          _selectLanguage = 1;
          break;
        case 'ru':
          _selectLanguage = 2;
          break;
        case 'ka':
          _selectLanguage = 3;
          break;
        case 'en':
          _selectLanguage = 4;
          break;
      }
    });
  }

  SoliqSelectButton({required int id, required String text}) {
    return Padding(
      padding:const EdgeInsets.symmetric(vertical: 8.0),
      child: Stack(
        alignment: Alignment.center,
        children: [
          ElevatedButton(
            style: ElevatedButton.styleFrom(
              elevation: 4.0,
              shadowColor: Colors.black12,
              backgroundColor: Colors.white,
              shape: RoundedRectangleBorder(
                  borderRadius: BorderRadius.circular(10.0)),
              padding:const EdgeInsets.symmetric(
                horizontal: 30,
                vertical: 18,
              ),
            ),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                Center(
                  child: Text(
                    text,
                    textAlign: TextAlign.center,
                    style:const TextStyle(
                      color: Colors.grey,
                      fontSize: 14,
                      fontFamily: 'Montserrat',
                      fontWeight: FontWeight.w500,
                    ),
                  ),
                ),
              ],
            ),
            onPressed: () => changeLanguage(id),
          ),
          Padding(
            padding: const EdgeInsets.only(right: 20.0),
            child: Align(
              alignment: Alignment.centerRight,
              child: _selectLanguage == id
                  ? SvgPicture.asset(
                      'lib/src/assets/icons/check.svg',
                      // color: primaryAppColor(context),
                    )
                  : Container(),
            ),
          )
        ],
      ),
    );
  }

  Future<void> changeLanguage(int id) async {
    try {
      setState(() {
        _loadingLanguage = true;
      });

      log("////////////////////////${langCode[id]}");

      await Utils.changeLanguage(context, langCode[id],
          changeOnServer: widget.changeOnServer);
      setState(() {
        _loadingLanguage = false;
      });
      Navigator.pop(context);
    } catch (e) {
      Logger().d(e);
    }
  }
}
